<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'type_birthday' => 'Augura buon compleanno a',
    'type_phone_call' => 'Chiama',
    'type_lunch' => 'Pranzo con',
    'type_hangout' => 'Incontro con',
    'type_email' => 'Email',
    'type_birthday_kid' => 'Augura buon compleanno al figlio di',
];
